#include "ArgParser.hpp"
#include "Helpers/WolframAlpha.hpp"
#include <iostream>
#include <nlohmann/json.hpp>
#include <print>

int main(const int argc, char* argv[]) {
  try {
    ArgParser args;
    args.addArg("-s", "--source", "Specify the source of the data (Wolfram|OpenFoodFacts)");
    args.addArg("-f", "--food", "Specify the food item");
    args.addArg("-a", "--amount", "Specify the amount (in grams)");
    args.addArg("-h", "--help", "Print help", false);
    args.parse(argc, argv);

    const auto   food   = args.get<std::string>("--food");
    const double amount = args.get<double>("--amount") / 100;

    if (!args.has("--source") || args.get<std::string>("--source") == "Wolfram") {
      WolframAlpha wa(food, amount);
      std::println("Calories: {:.2f} kcal\nProtein: {:.2f} g\nCarbs: {:.2f} g\nFat: {:.2f} g", wa.getCalories(), wa.getProtein(), wa.getCarbs(), wa.getFat());
    }
  } catch (const std::exception& e) {
    std::println(stderr, "Error: {}", e.what());
    return 1;
  } catch (...) {
    std::println(stderr, "Unknown error occurred.");
    return 1;
  }
}
